import Cache from 'tmp-cache';
import { BriskRoute } from './router/brisk.js';
import { RouteGroup } from './router/group.js';
import { RouteResource } from './router/resource.js';
const proxyCache = new Cache({ max: 200 });
export function dropSlash(input) {
    if (input === '/') {
        return '/';
    }
    return `/${input.replace(/^\//, '').replace(/\/$/, '')}`;
}
export function toRoutesJSON(routes) {
    return routes.reduce((list, route) => {
        if (route instanceof RouteGroup) {
            list = list.concat(toRoutesJSON(route.routes));
            return list;
        }
        if (route instanceof RouteResource) {
            list = list.concat(toRoutesJSON(route.routes));
            return list;
        }
        if (route instanceof BriskRoute) {
            if (route.route && !route.route.isDeleted()) {
                list.push(route.route.toJSON());
            }
            return list;
        }
        if (!route.isDeleted()) {
            list.push(route.toJSON());
        }
        return list;
    }, []);
}
export function trustProxy(remoteAddress, proxyFn) {
    if (proxyCache.has(remoteAddress)) {
        return proxyCache.get(remoteAddress);
    }
    const result = proxyFn(remoteAddress, 0);
    proxyCache.set(remoteAddress, result);
    return result;
}
