import { moduleImporter } from '@adonisjs/fold';
import { RuntimeException } from '@poppinss/utils';
export class MiddlewareStore {
    #namedMiddleware;
    #middleware;
    #resolvedMiddleware = new Map();
    constructor(middleware, namedMiddleware) {
        this.#middleware = middleware.map((one) => moduleImporter(one, 'handle').toHandleMethod());
        this.#namedMiddleware = namedMiddleware;
    }
    get(name, ...args) {
        if (this.#resolvedMiddleware.has(name)) {
            return {
                name,
                args: args[0],
                ...this.#resolvedMiddleware.get(name),
            };
        }
        if (!this.#namedMiddleware || !this.#namedMiddleware[name]) {
            throw new RuntimeException(`Cannot resolve "${String(name)}" middleware. Make sure the middleware is registered before using it`);
        }
        const handler = moduleImporter(this.#namedMiddleware[name], 'handle').toHandleMethod();
        this.#resolvedMiddleware.set(name, handler);
        return {
            name,
            args: args[0],
            ...handler,
        };
    }
    list() {
        return this.#middleware;
    }
}
