/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
import { Macroable } from '@poppinss/macroable';
import type { Encryption } from '@adonisjs/encryption';
import { UrlWithStringQuery } from 'node:url';
import { ServerResponse, IncomingMessage, IncomingHttpHeaders } from 'node:http';
import type { Qs } from './qs.js';
import { RequestConfig } from './types/request.js';
import type { HttpContext } from './http_context/main.js';
export declare class Request extends Macroable {
    #private;
    request: IncomingMessage;
    response: ServerResponse;
    parsedUrl: UrlWithStringQuery;
    ctx?: HttpContext;
    constructor(request: IncomingMessage, response: ServerResponse, encryption: Encryption, config: RequestConfig, qsParser: Qs);
    id(): string | undefined;
    setInitialBody(body: Record<string, any>): void;
    updateBody(body: Record<string, any>): void;
    updateRawBody(rawBody: string): void;
    updateQs(data: Record<string, any>): void;
    params(): Record<string, any>;
    qs(): Record<string, any>;
    body(): Record<string, any>;
    all(): Record<string, any>;
    original(): Record<string, any>;
    raw(): string | null;
    input(key: string, defaultValue?: any): any;
    param(key: string, defaultValue?: any): any;
    except(keys: string[]): Record<string, any>;
    only<T extends string>(keys: T[]): {
        [K in T]: any;
    };
    intended(): string;
    method(): string;
    headers(): IncomingHttpHeaders;
    header(key: string, defaultValue?: any): string | undefined;
    ip(): string;
    ips(): string[];
    protocol(): string;
    secure(): boolean;
    host(): string | null;
    hostname(): string | null;
    subdomains(): string[];
    ajax(): boolean;
    pjax(): boolean;
    url(includeQueryString?: boolean): string;
    completeUrl(includeQueryString?: boolean): string;
    matchesRoute(routeIdentifier: string | string[]): boolean;
    is(types: string[]): string | null;
    accepts<T extends string>(types: T[]): T | null;
    types(): string[];
    language<T extends string>(languages: T[]): T | null;
    languages(): string[];
    charset<T extends string>(charsets: T[]): T | null;
    charsets(): string[];
    encoding<T extends string>(encodings: T[]): T | null;
    encodings(): string[];
    hasBody(): boolean;
    fresh(): boolean;
    stale(): boolean;
    cookiesList(): Record<string, any>;
    cookie(key: string, defaultValue?: string): any;
    encryptedCookie(key: string, defaultValue?: string): any;
    plainCookie(key: string, defaultValue?: string, encoded?: boolean): any;
    hasValidSignature(purpose?: string): boolean;
    toJSON(): {
        id: string | undefined;
        url: string;
        query: string | null;
        body: Record<string, any>;
        params: Record<string, any>;
        headers: IncomingHttpHeaders;
        method: string;
        protocol: string;
        cookies: Record<string, any>;
        hostname: string | null;
        ip: string;
        subdomains: Record<string, any>;
    };
}
