/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
import { Macroable } from '@poppinss/macroable';
import type { Encryption } from '@adonisjs/encryption';
import { ServerResponse, IncomingMessage } from 'node:http';
import type { Qs } from './qs.js';
import { Redirect } from './redirect.js';
import type { Router } from './router/main.js';
import type { HttpContext } from './http_context/main.js';
import type { CastableHeader, CookieOptions, ResponseConfig, ResponseStream } from './types/response.js';
export declare class Response extends Macroable {
    #private;
    request: IncomingMessage;
    response: ServerResponse;
    get hasLazyBody(): boolean;
    get isStreamResponse(): boolean;
    lazyBody: Partial<{
        content: [any, boolean, string?];
        stream: [ResponseStream, ((error: NodeJS.ErrnoException) => [string, number?])?];
        fileToStream: [string, boolean, ((error: NodeJS.ErrnoException) => [string, number?])?];
    }>;
    ctx?: HttpContext;
    constructor(request: IncomingMessage, response: ServerResponse, encryption: Encryption, config: ResponseConfig, router: Router, qs: Qs);
    get finished(): boolean;
    get headersSent(): boolean;
    get isPending(): boolean;
    protected writeBody(content: any, generateEtag: boolean, jsonpCallbackName?: string): void;
    protected streamBody(body: ResponseStream, errorCallback?: (error: NodeJS.ErrnoException) => [string, number?]): Promise<void>;
    protected streamFileForDownload(filePath: string, generateEtag: boolean, errorCallback?: (error: NodeJS.ErrnoException) => [string, number?]): Promise<void>;
    flushHeaders(statusCode?: number): this;
    getHeader(key: string): import("http").OutgoingHttpHeader | undefined;
    getHeaders(): {
        [x: string]: import("http").OutgoingHttpHeader | undefined;
    };
    header(key: string, value: CastableHeader): this;
    append(key: string, value: CastableHeader): this;
    safeHeader(key: string, value: CastableHeader): this;
    removeHeader(key: string): this;
    getStatus(): number;
    status(code: number): this;
    safeStatus(code: number): this;
    type(type: string, charset?: string): this;
    vary(field: string | string[]): this;
    setEtag(body: any, weak?: boolean): this;
    fresh(): boolean;
    getBody(): any;
    send(body: any, generateEtag?: boolean): void;
    json(body: any, generateEtag?: boolean): void;
    jsonp(body: any, callbackName?: string, generateEtag?: boolean): void;
    stream(body: ResponseStream, errorCallback?: (error: NodeJS.ErrnoException) => [string, number?]): void;
    download(filePath: string, generateEtag?: boolean, errorCallback?: (error: NodeJS.ErrnoException) => [string, number?]): void;
    attachment(filePath: string, name?: string, disposition?: string, generateEtag?: boolean, errorCallback?: (error: NodeJS.ErrnoException) => [string, number?]): void;
    location(url: string): this;
    redirect(): Redirect;
    redirect(path: string, forwardQueryString?: boolean, statusCode?: number): void;
    abort(body: any, status?: number): never;
    abortIf(condition: unknown, body: any, status?: number): asserts condition is undefined | null | false;
    abortUnless<T>(condition: T, body: any, status?: number): asserts condition is Exclude<T, undefined | null | false>;
    cookie(key: string, value: any, options?: Partial<CookieOptions>): this;
    encryptedCookie(key: string, value: any, options?: Partial<CookieOptions>): this;
    plainCookie(key: string, value: any, options?: Partial<CookieOptions & {
        encode: boolean;
    }>): this;
    clearCookie(key: string, options?: Partial<CookieOptions>): this;
    finish(): void;
    continue(): void;
    switchingProtocols(): void;
    ok(body: any, generateEtag?: boolean): void;
    created(body?: any, generateEtag?: boolean): void;
    accepted(body: any, generateEtag?: boolean): void;
    nonAuthoritativeInformation(body: any, generateEtag?: boolean): void;
    noContent(): void;
    resetContent(): void;
    partialContent(body: any, generateEtag?: boolean): void;
    multipleChoices(body?: any, generateEtag?: boolean): void;
    movedPermanently(body?: any, generateEtag?: boolean): void;
    movedTemporarily(body?: any, generateEtag?: boolean): void;
    seeOther(body?: any, generateEtag?: boolean): void;
    notModified(body?: any, generateEtag?: boolean): void;
    useProxy(body?: any, generateEtag?: boolean): void;
    temporaryRedirect(body?: any, generateEtag?: boolean): void;
    badRequest(body?: any, generateEtag?: boolean): void;
    unauthorized(body?: any, generateEtag?: boolean): void;
    paymentRequired(body?: any, generateEtag?: boolean): void;
    forbidden(body?: any, generateEtag?: boolean): void;
    notFound(body?: any, generateEtag?: boolean): void;
    methodNotAllowed(body?: any, generateEtag?: boolean): void;
    notAcceptable(body?: any, generateEtag?: boolean): void;
    proxyAuthenticationRequired(body?: any, generateEtag?: boolean): void;
    requestTimeout(body?: any, generateEtag?: boolean): void;
    conflict(body?: any, generateEtag?: boolean): void;
    gone(body?: any, generateEtag?: boolean): void;
    lengthRequired(body?: any, generateEtag?: boolean): void;
    preconditionFailed(body?: any, generateEtag?: boolean): void;
    requestEntityTooLarge(body?: any, generateEtag?: boolean): void;
    requestUriTooLong(body?: any, generateEtag?: boolean): void;
    unsupportedMediaType(body?: any, generateEtag?: boolean): void;
    requestedRangeNotSatisfiable(body?: any, generateEtag?: boolean): void;
    expectationFailed(body?: any, generateEtag?: boolean): void;
    unprocessableEntity(body?: any, generateEtag?: boolean): void;
    tooManyRequests(body?: any, generateEtag?: boolean): void;
    internalServerError(body?: any, generateEtag?: boolean): void;
    notImplemented(body?: any, generateEtag?: boolean): void;
    badGateway(body?: any, generateEtag?: boolean): void;
    serviceUnavailable(body?: any, generateEtag?: boolean): void;
    gatewayTimeout(body?: any, generateEtag?: boolean): void;
    httpVersionNotSupported(body?: any, generateEtag?: boolean): void;
}
