import { CannotLookupRouteException } from '../../exceptions/cannot_lookup_route.js';
export class RouteFinder {
    #routes;
    constructor(routes) {
        this.#routes = routes;
    }
    find(routeIdentifier) {
        return (this.#routes.find(({ name, pattern, handler }) => {
            if (name === routeIdentifier || pattern === routeIdentifier) {
                return true;
            }
            if (typeof handler === 'function') {
                return false;
            }
            return handler.name === routeIdentifier;
        }) || null);
    }
    findOrFail(routeIdentifier) {
        const route = this.find(routeIdentifier);
        if (!route) {
            throw new CannotLookupRouteException(`Cannot lookup route "${routeIdentifier}"`);
        }
        return route;
    }
    has(routeIdentifier) {
        return !!this.find(routeIdentifier);
    }
}
