import type { Encryption } from '@adonisjs/encryption';
import type { Application } from '@adonisjs/application';
import type { Qs } from '../qs.js';
import { Route } from './route.js';
import { RouteGroup } from './group.js';
import { BriskRoute } from './brisk.js';
import { RouteResource } from './resource.js';
import { LookupStore } from './lookup_store/main.js';
import { RouteMatchers as Matchers } from './matchers.js';
import type { LazyImport } from '../types/base.js';
import { MiddlewareStore } from '../middleware/store.js';
import type { MiddlewareAsClass } from '../types/middleware.js';
import type { RouteFn, MatchedRoute, RouteMatcher, MakeUrlOptions, MakeSignedUrlOptions } from '../types/route.js';
export declare class Router<NamedMiddleware extends Record<string, LazyImport<MiddlewareAsClass>> = any> extends LookupStore {
    #private;
    routes: (Route<NamedMiddleware> | RouteResource<NamedMiddleware> | RouteGroup<NamedMiddleware> | BriskRoute<NamedMiddleware>)[];
    usingDomains: boolean;
    matchers: Matchers;
    constructor(app: Application<any, any, any>, encryption: Encryption, middlewareStore: MiddlewareStore<NamedMiddleware>, qsParser: Qs);
    route(pattern: string, methods: string[], handler: string | RouteFn): Route<NamedMiddleware>;
    any(pattern: string, handler: string | RouteFn): Route<NamedMiddleware>;
    get(pattern: string, handler: string | RouteFn): Route<NamedMiddleware>;
    post(pattern: string, handler: string | RouteFn): Route<NamedMiddleware>;
    put(pattern: string, handler: string | RouteFn): Route<NamedMiddleware>;
    patch(pattern: string, handler: string | RouteFn): Route<NamedMiddleware>;
    delete(pattern: string, handler: string | RouteFn): Route<NamedMiddleware>;
    group(callback: () => void): RouteGroup<NamedMiddleware>;
    resource(resource: string, controller: string): RouteResource<NamedMiddleware>;
    shallowResource(resource: string, controller: string): RouteResource<NamedMiddleware>;
    on(pattern: string): BriskRoute<NamedMiddleware>;
    where(param: string, matcher: RouteMatcher | string | RegExp): this;
    commit(): void;
    match(url: string, method: string, hostname?: string | null): null | MatchedRoute;
    makeUrl(routeIdentifier: string, params?: any[] | Record<string, any>, options?: MakeUrlOptions): string;
    makeSignedUrl(routeIdentifier: string, params?: any[] | Record<string, any>, options?: MakeSignedUrlOptions): string;
}
